{   GNU Pascal Interface to SDLGfx. 
    Copyright (C) 2002 by Eike Lange
    
    This unit is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This unit is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this unit; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Eike Lange, eike@gnu.de
    http://www.gnu-pascal.de/~contrib/eike/

    This unit was implemented using version 2.0.3 of libSDL_gfx. 
    Color Values MUST be of 16#RRGGBBAA, AA* means Anti Aliased
    Some header files and/or routines were not supported:
      Missing:
        SDL_framerate.h, SDL_imageFilter.h, SDL_rotozoom.h
        (everything except SDL_gfxPrimitives.h)
}

{$if __GPC_RELEASE__ < 20020225}
{$error This unit requires GPC release 20020225 or newer.}
{$endif}

unit SdlGfx;

interface

uses SDL;

type
  { Just for polygon routines }
  TPolyArray = array [0.. High (ShortInt) div SizeOf (ShortInt)] of ShortInt;

  {@section Routines From SDL_gfxPrimitives.h }

{ Pixel }
function PixelColor (Dst: PSdlSurface; x, y: ShortInt;
  Color: Cardinal): Integer; asmname 'pixelColor';
function PixelRGBA (Dst: PSdlSurface; x, y: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'pixelRGBA';

{ Horizontal Line }
function HLineColor (Dst: PSdlSurface; x1, x2, y: ShortInt;
  Color: Cardinal): Integer; asmname 'hlineColor';
function HLineRGBA (Dst: PSdlSurface; x1, x2, y: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'hlineRGBA';

{ Vertical Line }
function VLineColor (Dst: PSdlSurface; x, y1, y2: ShortInt;
  Color: Cardinal): Integer; asmname 'vlineColor';
function VLineRGBA (Dst: PSdlSurface; x, y1, y2: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'vlineRGBA';

{ Vertical Line }
function VLineColor (Dst: PSdlSurface; x, y1, y2: ShortInt;
  Color: Cardinal): Integer; asmname 'vlineColor';
function VLineRGBA (Dst: PSdlSurface; x, y1, y2: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'vlineRGBA';

{ Rectangle }
function RectangleColor (Dst: PSdlSurface; x1, y1, x2, y2: ShortInt;
  Color: Cardinal): Integer; asmname 'rectangleColor';
function RectangleRGBA (Dst: PSdlSurface; x1, y1, x2, y2: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'rectangleRGBA';

{ Filled rectangle (Box) }
function BoxColor (Dst: PSdlSurface; x1, y1, x2, y2: ShortInt;
  Color: Cardinal): Integer; asmname 'boxColor';
function BoxRGBA (Dst: PSdlSurface; x1, y1, x2, y2: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'boxRGBA';

{ Line }
function LineColor (Dst: PSdlSurface; x1, y1, x2, y2: ShortInt;
  Color: Cardinal): Integer; asmname 'lineColor';
function LineRGBA (Dst: PSdlSurface; x1, y1, x2, y2: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'lineRGBA';

{ Anti Aliased Line }
function AALineColor (Dst: PSdlSurface; x1, y1, x2, y2: ShortInt;
  Color: Cardinal): Integer; asmname 'aalineColor';
function AALineRGBA (Dst: PSdlSurface; x1, y1, x2, y2: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'aalineRGBA';

{ Circle }
function CircleColor (Dst: PSdlSurface; x, y, r: ShortInt;
  Color: Cardinal): Integer; asmname 'circleColor';
function CircleRGBA (Dst: PSdlSurface; x, y, rad: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'circleRGBA';

{ Anti Aliased Circle }
function AACircleColor (Dst: PSdlSurface; x, y, r: ShortInt;
  Color: Cardinal): Integer; asmname 'aacircleColor';
function AACircleRGBA (Dst: PSdlSurface; x, y, rad: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'aacircleRGBA';

{ Filled Circle }
function FilledCircleColor (Dst: PSdlSurface; x, y, r: ShortInt;
  Color: Cardinal): Integer; asmname 'filledCircleColor';
function FilledCircleRGBA (Dst: PSdlSurface; x, y, rad: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'filledCircleRGBA';

{ Ellipse }
function EllipseColor (Dst: PSdlSurface; x, y, rx, ry: ShortInt;
  Color: Cardinal): Integer; asmname 'ellipseColor';
function EllipseRGBA (Dst: PSdlSurface; x, y, rx, ry: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'ellipseRGBA';

{ Anti Aliased Ellipse }
function AAEllipseColor (Dst: PSdlSurface; x, y, rx, ry: ShortInt;
  Color: Cardinal): Integer; asmname 'aaellipseColor';
function AAEllipseRGBA (Dst: PSdlSurface; x, y, rx, ry: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'aaellipseRGBA';

{ Filled Ellipse }
function FilledEllipseColor (Dst: PSdlSurface; x, y, rx, ry: ShortInt;
  Color: Cardinal): Integer; asmname 'filledEllipseColor';
function FilledEllipseRGBA (Dst: PSdlSurface; x, y, rx, ry: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'filledEllipseRGBA';

{ Filled Pie }
function FilledPieColor (Dst: PSdlSurface; x, y, rad, AngleBegin, AngleEnd: ShortInt;
  Color: Cardinal): Integer; asmname 'filledpieColor';
function FilledPieRGBA (Dst: PSdlSurface; x, y, rad, AngleBegin, AngleEnd: ShortInt;
  R, G, B, A: ByteCard): Integer; asmname 'filledpieRGBA';

{ Polygon }
function PolygonColor (Dst: PSdlSurface; var vx, vy: TPolyArray; Num: Integer;
  Color: Cardinal): Integer; asmname 'polygonColor';
function PolygonRGBA (Dst: PSdlSurface; var vx, vy: TPolyArray; Num: Integer;
  R, G, B, A: ByteCard): Integer; asmname 'polygonRGBA';
  
{ AA-Polygon }
function AAPolygonColor (Dst: PSdlSurface; var vx, vy: TPolyArray; Num: Integer;
  Color: Cardinal): Integer; asmname 'aapolygonColor';
function AAPolygonRGBA (Dst: PSdlSurface; var vx, vy: TPolyArray; Num: Integer;
  R, G, B, A: ByteCard): Integer; asmname 'polygonRGBA';

{ Filled Polygon }
function FilledPolygonColor (Dst: PSdlSurface; var vx, vy: TPolyArray; Num: Integer;
  Color: Cardinal): Integer; asmname 'filledPolygonColor';
function FilledPolygonRGBA (Dst: PSdlSurface; var vx, vy: TPolyArray; Num: Integer;
  R, G, B, A: ByteCard): Integer; asmname 'filledPolygonRGBA';

{ 8x8 Characters/Strings }
function CharacterColor (Dst: PSdlSurface; x, y: ShortInt; c: Char;
  Color: Cardinal): Integer; asmname 'characterColor';
function CharacterRGBA (Dst: PSdlSurface; x, y: ShortInt; c: Char;
  R, G, B, A: ByteCard): Integer; asmname 'characterRGBA';
function StringColor (Dst: PSdlSurface; x, y: ShortInt; s: SdlString;
  Color: Cardinal): Integer;
function StringRGBA (Dst: PSdlSurface; x, y: ShortInt; s: SdlString;
  R, G, B, A: ByteCard): Integer;


implementation

{$L SDL_gfx}

function CStringColor (Dst: PSdlSurface; x, y: ShortInt; s: PChar;
  Color: Cardinal): Integer; asmname 'stringColor';
function StringColor (Dst: PSdlSurface; x, y: ShortInt; s: SdlString;
  Color: Cardinal): Integer;
begin
  StringColor := CStringColor (Dst, x, y, String2CString (s), Color)
end;

function CStringRGBA (Dst: PSdlSurface; x, y: ShortInt; s: PChar;
  R, G, B, A: ByteCard): Integer; asmname 'stringRGBA';
function StringRGBA (Dst: PSdlSurface; x, y: ShortInt; s: SdlString;
  R, G, B, A: ByteCard): Integer; 
begin
  StringRGBA := CStringRGBA (Dst, x, y, String2CString (s), R, G, B, A)
end;

end.
